//
//  DateCondition.m
//  iBal2
//
//  Created by Ken Kawamoto on Thu Aug 26 2004.
//  Copyright (c) 2004 AngryFish. All rights reserved.
//

#import "DateCondition.h"
#import "IO.h"
#import "DateConditionView.h"

@implementation DateCondition

//アーカイブから初期化
- (id)initWithCoder:(NSCoder *)coder{
	[super initWithCoder:coder];
	[self setPeriodID: [[coder decodeObject]intValue]];
	
	return self;
}
//アーカイブにエンコード
- (void)encodeWithCoder:(NSCoder *)coder{
	[super encodeWithCoder:coder];
	[coder encodeObject:[NSDecimalNumber numberWithInt:periodID]];
}

- (void)setPeriodID:(int)newPeriodID{
	periodID=newPeriodID;
}
- (int)periodID{
	return periodID;
}

- (DateCondition *)copy{
	DateCondition *newCond=[[DateCondition alloc]initWithCondition:self];
	[newCond setPeriodID:periodID];
	return newCond;
}

//IO matches condition
- (BOOL)ioMatchesCondition:(IO *)record{
	NSCalendarDate *date=[record date];
	switch([super conditionTypeCode]){
		case kCondition_is:
		case kCondition_isnt:
		case kCondition_biggerThan:
		case kCondition_smallerThan:
		case kCondition_between:
		case kCondition_notBetween:
			return [super standardComparison:date];
		case kCondition_inPeriod:
			return [[self criticalDate]compare:date]==NSOrderedAscending;
		case kCondition_notInPeriod:
			return [[self criticalDate]compare:date]==NSOrderedDescending;
	}
	return YES;
}

- (NSCalendarDate *)criticalDate{
	switch(periodID){
		case kConditionPeriod_days:
			return [[NSCalendarDate calendarDate] dateByAddingYears:0 months:0 days:-[[super object] intValue] hours:0 minutes:0 seconds:0];
		case kConditionPeriod_weeks:
			return [[NSCalendarDate calendarDate] dateByAddingYears:0 months:0 days:-[[super object] intValue]*7 hours:0 minutes:0 seconds:0];
			break;
		case kConditionPeriod_months:
			return [[NSCalendarDate calendarDate] dateByAddingYears:0 months:-[[super object] intValue] days:0 hours:0 minutes:0 seconds:0];
	}
	return nil;
}


- (ConditionView *)conditionView{
	DateConditionView *newView=[[DateConditionView alloc]init];
	
	//set the what ID
	[newView setWhatToID: conditionTypeCode];
	
	switch(conditionTypeCode){
		case kCondition_inPeriod:
		case kCondition_notInPeriod:
			[[newView periodField]setObjectValue:[self object]];
			break;
		case kCondition_between:
		case kCondition_notBetween:
			[[newView dateUpperLimitField]setObjectValue:[self object2]];
		default:
			[[newView dateField]setObjectValue:[self object]];
	}
	
	[newView sizeToFit];
	
	return newView;
}

@end
